@@ -25,7 +25,7 @@
 #'
 addMask <- function(mask, add = TRUE, col='black'){
   wd <- getwd()
-  setwd(gettmpdir())
+  setwd(tempdir())
   writeTIFF(mask*1, 'tmp.tif')
   rmask <- raster('tmp.tif')
   rmask[rmask!=0] <- NA
